@@ -1,3 +1,4 @@
+from phonepiece.iso import normalize_lang_id
 from transphone.lang.base_tokenizer import BaseTokenizer
 from transphone.lang.eng.tokenizer import ENGTokenizer
 from transphone.lang.cmn.tokenizer import CMNTokenizer
@@ -5,6 +6,9 @@ from transphone.lang.jpn.tokenizer import JPNTokenizer
 
 
 def read_tokenizer(lang_id, g2p_model='latest'):
+
+    lang_id = normalize_lang_id(lang_id)
+
     if lang_id == 'eng':
         tokenizer = ENGTokenizer(lang_id, g2p_model)
     elif lang_id == 'cmn':
